# Cloud Forensics Utils

<p align="center">
  <img src="https://user-images.githubusercontent.com/25910997/81309523-533f6300-9083-11ea-975b-668f550e5a9e.png" width="300"/>
</p>

This repository contains some tools to be used by forensics teams to collect
evidence from cloud platforms. Currently, Google Cloud Platform and Amazon Web Services are supported.

## Quick install

```
pip install libcloudforensics
```
